@@ -152,16 +152,21 @@ For example, search(coverage_format="wkt") is identical to using include_coverag
 """
             )
 
+        if coverage_crs is not None or coverage_format is not None:
+            coverage = get_coverage_spec(coverage_crs, coverage_format)
+        else:
+            coverage = None
+
         if get_all:
-            req = SearchSeismicsRequest()
+            req = SearchSeismicsRequest(coverage=coverage)
         else:
             spec = get_search_spec(id, external_id, external_id_substring, name, name_substring)
             if mode == "seismic":
-                req = SearchSeismicsRequest(seismic=spec)
+                req = SearchSeismicsRequest(seismic=spec, coverage=coverage)
             elif mode == "survey":
-                req = SearchSeismicsRequest(survey=spec)
+                req = SearchSeismicsRequest(survey=spec, coverage=coverage)
             elif mode == "partition":
-                req = SearchSeismicsRequest(partition=spec)
+                req = SearchSeismicsRequest(partition=spec, coverage=coverage)
             else:
                 raise Exception("mode should be one of: survey, seismic, partition")
 
@@ -171,8 +176,6 @@ For example, search(coverage_format="wkt") is identical to using include_coverag
         req.include_volume_definition = include_volume_definition
         req.include_seismic_store = include_seismic_store
         req.include_partition = include_partition
-        if coverage_crs is not None or coverage_format is not None:
-            req.coverage = get_coverage_spec(coverage_crs, coverage_format)
 
         results = self.query.SearchSeismics(req, metadata=self.metadata)
         return [Seismic.from_proto(s) for s in results]
