@@ -29,7 +29,7 @@ class SeismicStoreAPI(API):
         get_all: bool = False,
         include_file_info: bool = False,
         include_headers: bool = False,
-        include_volume_definitions: bool = True,
+        include_volume_definitions: bool = False,
         include_coverage: bool = False,
         coverage_crs: MaybeString = None,
         coverage_format: MaybeString = None,
@@ -65,20 +65,22 @@ For example, search(coverage_format="wkt") is identical to using include_coverag
 """
             )
 
+        if coverage_crs is not None or coverage_format is not None:
+            coverage = get_coverage_spec(coverage_crs, coverage_format)
+        else:
+            coverage = None
+
         if get_all:
             req = SearchSeismicStoresRequest()
         else:
             spec = get_search_spec(id, external_id, external_id_substring, name, name_substring)
             if mode == "seismic_store":
-                req = SearchSeismicStoresRequest(seismic_store=spec)
+                req = SearchSeismicStoresRequest(seismic_store=spec, coverage=coverage)
             elif mode == "survey":
-                req = SearchSeismicStoresRequest(survey=spec)
+                req = SearchSeismicStoresRequest(survey=spec, coverage=coverage)
             else:
                 raise Exception("mode should be one of: survey, seismic_store")
 
-        if coverage_crs is not None or coverage_format is not None:
-            req.coverage = get_coverage_spec(coverage_crs, coverage_format)
-
         req.include_file_info = include_file_info
         req.include_headers = include_headers
         req.include_volume_definitions = include_volume_definitions
@@ -86,18 +88,23 @@ For example, search(coverage_format="wkt") is identical to using include_coverag
         results = self.query.SearchSeismicStores(req, metadata=self.metadata)
         return [SeismicStore.from_proto(p) for p in results]
 
-    def list(self, *, include_file_info: bool = False) -> Iterable[SeismicStore]:
+    def list(
+        self, *, include_file_info: bool = False, include_volume_definitions: bool = False
+    ) -> Iterable[SeismicStore]:
         """List all visible seismic stores.
 
         List all visible seismic stores. This is equivalent to calling search() with get_all=true.
 
         Args:
             include_file_info (bool): (Optional) If true, the response will include information on the source file.
+            include_volume_definitions (bool): (Optional) If true, the response will include volume definitions.
 
         Returns:
             Iterable[:py:class:`~cognite.seismic.data_classes.api_types.SeismicStore`]: The list of visible seismic stores
         """
-        return self.search(get_all=True, include_file_info=include_file_info)
+        return self.search(
+            get_all=True, include_file_info=include_file_info, include_volume_definitions=include_volume_definitions
+        )
 
     def get(self, id: int, *, coverage_crs: MaybeString = None, coverage_format: MaybeString = None) -> SeismicStore:
         """Get a seismic store by its id.
