@@ -10,7 +10,7 @@ if not os.getenv("READ_THE_DOCS"):
         SearchPartitionsRequest,
     )
 else:
-    from cognite.seismic._api.shims import Identifier
+    from cognite.seismic._api.shims import CoverageSpec, Identifier
 
 
 MaybeString = Optional[str]
@@ -66,15 +66,14 @@ def get_search_spec(
     return spec
 
 
-def get_coverage_spec(crs: Optional[str], format: Optional[str]) -> CoverageSpec:
-    """Turns an optional crs and an optional string into a CoverageSpec.
-    """
+def get_coverage_spec(crs: Optional[str] = None, format: Optional[str] = None) -> CoverageSpec:
+    """Turns an optional crs and an optional string into a CoverageSpec."""
     if format == None:
         format = "wkt"
 
     if format == "wkt":
-        return CoverageSpec(crs=coverage_crs, format=0)
+        return CoverageSpec(crs=crs, format=0)
     elif format == "geojson":
-        return CoverageSpec(crs=coverage_crs, format=1)
+        return CoverageSpec(crs=crs, format=1)
     else:
         raise ValueError(f"Unknown format {format}")
